Module: Google::Cloud::CloudSecurityCompliance
- Defined in:
- lib/google/cloud/cloud_security_compliance.rb,
lib/google/cloud/cloud_security_compliance/version.rb
Constant Summary collapse
- VERSION =
"0.4.0"
Class Method Summary collapse
-
.audit(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Audit.
-
.audit_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Audit service is supported by the current client.
-
.cm_enrollment_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CmEnrollmentService.
-
.cm_enrollment_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CmEnrollmentService service is supported by the current client.
-
.config(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Config.
-
.config_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Config service is supported by the current client.
-
.configure {|::Google::Cloud.configure.cloud_security_compliance| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_security_compliance library.
-
.deployment(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Deployment.
-
.deployment_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Deployment service is supported by the current client.
-
.monitoring(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Monitoring.
-
.monitoring_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Monitoring service is supported by the current client.
Class Method Details
.audit(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Audit.
By default, this returns an instance of
Google::Cloud::CloudSecurityCompliance::V1::Audit::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Audit service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Audit service. You can determine whether the method will succeed by calling audit_available?.
About Audit
Service describing handlers for resources
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 75 def self.audit version: :v1, transport: :grpc, &block require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudSecurityCompliance.const_get(package_name).const_get(:Audit) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.audit_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Audit service is supported by the current client. If true, you can retrieve a client object by calling audit. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Audit service, or if the versioned client gem needs an update to support the Audit service.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 99 def self.audit_available? version: :v1, transport: :grpc require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudSecurityCompliance.const_get package_name return false unless service_module.const_defined? :Audit service_module = service_module.const_get :Audit if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.cm_enrollment_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CmEnrollmentService.
By default, this returns an instance of
Google::Cloud::CloudSecurityCompliance::V1::CmEnrollmentService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CmEnrollmentService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CmEnrollmentService service. You can determine whether the method will succeed by calling cm_enrollment_service_available?.
About CmEnrollmentService
Service describing CmEnrollment related RPCs for complianceManager.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 146 def self.cm_enrollment_service version: :v1, transport: :grpc, &block require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudSecurityCompliance.const_get(package_name).const_get(:CmEnrollmentService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.cm_enrollment_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CmEnrollmentService service is supported by the current client. If true, you can retrieve a client object by calling cm_enrollment_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CmEnrollmentService service, or if the versioned client gem needs an update to support the CmEnrollmentService service.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 170 def self.cm_enrollment_service_available? version: :v1, transport: :grpc require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudSecurityCompliance.const_get package_name return false unless service_module.const_defined? :CmEnrollmentService service_module = service_module.const_get :CmEnrollmentService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.config(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Config.
By default, this returns an instance of
Google::Cloud::CloudSecurityCompliance::V1::Config::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Config service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Config service. You can determine whether the method will succeed by calling config_available?.
About Config
Config Service manages compliance frameworks, cloud controls, and their configurations.
217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 217 def self.config version: :v1, transport: :grpc, &block require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudSecurityCompliance.const_get(package_name).const_get(:Config) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.config_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Config service is supported by the current client. If true, you can retrieve a client object by calling config. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Config service, or if the versioned client gem needs an update to support the Config service.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 241 def self.config_available? version: :v1, transport: :grpc require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudSecurityCompliance.const_get package_name return false unless service_module.const_defined? :Config service_module = service_module.const_get :Config if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.cloud_security_compliance| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_security_compliance library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
430 431 432 433 434 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 430 def self.configure yield ::Google::Cloud.configure.cloud_security_compliance if block_given? ::Google::Cloud.configure.cloud_security_compliance end |
.deployment(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Deployment.
By default, this returns an instance of
Google::Cloud::CloudSecurityCompliance::V1::Deployment::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Deployment service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Deployment service. You can determine whether the method will succeed by calling deployment_available?.
About Deployment
Deployment service allows users to manage deployments of Frameworks and Cloud Controls on a target resource.
288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 288 def self.deployment version: :v1, transport: :grpc, &block require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudSecurityCompliance.const_get(package_name).const_get(:Deployment) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.deployment_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Deployment service is supported by the current client. If true, you can retrieve a client object by calling deployment. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Deployment service, or if the versioned client gem needs an update to support the Deployment service.
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 312 def self.deployment_available? version: :v1, transport: :grpc require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudSecurityCompliance.const_get package_name return false unless service_module.const_defined? :Deployment service_module = service_module.const_get :Deployment if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.monitoring(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Monitoring.
By default, this returns an instance of
Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Monitoring service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Monitoring service. You can determine whether the method will succeed by calling monitoring_available?.
About Monitoring
Service describing handlers for resources
358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 358 def self.monitoring version: :v1, transport: :grpc, &block require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudSecurityCompliance.const_get(package_name).const_get(:Monitoring) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.monitoring_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Monitoring service is supported by the current client. If true, you can retrieve a client object by calling monitoring. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Monitoring service, or if the versioned client gem needs an update to support the Monitoring service.
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/google/cloud/cloud_security_compliance.rb', line 382 def self.monitoring_available? version: :v1, transport: :grpc require "google/cloud/cloud_security_compliance/#{version.to_s.downcase}" package_name = Google::Cloud::CloudSecurityCompliance .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudSecurityCompliance.const_get package_name return false unless service_module.const_defined? :Monitoring service_module = service_module.const_get :Monitoring if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |